#[non_exhaustive]pub enum KeyDataStatus {
Unparsed,
Decoded,
DecodeError,
}Expand description
Inspection state for public-key bytes, separate from algorithm parameters.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unparsed
The algorithm or curve has no supported key representation here.
Decoded
Supported encoding/length was decoded; mathematical key validity is not checked.
DecodeError
A supported key encoding has invalid structure, length or unused bits.