#[non_exhaustive]pub struct AlgorithmInfo {
pub oid: String,
pub name: Option<String>,
pub parameters_der: Option<Vec<u8>>,
pub parameter_status: ParameterStatus,
pub pss: Option<PssParameters>,
}Expand description
Algorithm information with an optional common label and preserved parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.oid: StringDotted-decimal algorithm OID; always retained even if unrecognized.
name: Option<String>Common algorithm label. Recognition does not imply validity or support for use.
parameters_der: Option<Vec<u8>>DER encoding of parameters, when present. Original certificate DER is retained too.
parameter_status: ParameterStatusWhether the parameters were absent, decoded, unparsed or failed decoding.
pss: Option<PssParameters>Decoded RSA-PSS parameters, when available.